@@ -1,5 +1,6 @@
 /* asn1Parser.c -- program to parse a file with ASN1 definitions
- * Copyright (C) 2002-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+ * Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -33,9 +34,9 @@
 
 /* This feature is available in gcc versions 2.5 and later.  */
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
-#define ATTR_NO_RETRUN
+# define ATTR_NO_RETRUN
 #else
-#define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
+# define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
 #endif
 
 ATTR_NO_RETRUN static void
@@ -80,7 +81,7 @@ main (int argc, char *argv[])
   char *inputFileName = NULL;
   char *vectorName = NULL;
   int checkSyntaxOnly = 0;
-  asn1_node pointer = NULL;
+  ASN1_TYPE pointer = ASN1_TYPE_EMPTY;
   char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   int parse_result = ASN1_SUCCESS;
 
@@ -100,11 +101,10 @@ main (int argc, char *argv[])
       switch (option_result)
 	{
 	case 0:
-	  fprintf (stderr, "option %s",
-	           long_options[option_index].name);
+	  printf ("option %s", long_options[option_index].name);
 	  if (optarg)
-	    fprintf (stderr, " with arg %s", optarg);
-	  putc ('\n', stderr);
+	    printf (" with arg %s", optarg);
+	  printf ("\n");
 	  break;
 	case 'h':		/* HELP */
 	  free (outputFileName);
@@ -171,20 +171,18 @@ main (int argc, char *argv[])
   switch (parse_result)
     {
     case ASN1_SUCCESS:
-      fputs ("Done.\n", stderr);
+      printf ("Done.\n");
       break;
     case ASN1_FILE_NOT_FOUND:
-      fprintf (stderr, "asn1Parser: file %s was not found\n",
-               inputFileName);
+      printf ("asn1Parser: FILE %s NOT FOUND\n", inputFileName);
       break;
     case ASN1_SYNTAX_ERROR:
     case ASN1_IDENTIFIER_NOT_FOUND:
     case ASN1_NAME_TOO_LONG:
-      fprintf (stderr, "asn1Parser: %s\n", errorDescription);
+      printf ("asn1Parser: %s\n", errorDescription);
       break;
     default:
-      fprintf (stderr, "libtasn1 ERROR: %s\n",
-               asn1_strerror (parse_result));
+      printf ("libtasn1 ERROR: %s\n", asn1_strerror (parse_result));
     }
 
 
